package com.unipi.talepis.demomed3;

import org.springframework.web.bind.annotation.*;

import java.sql.*;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.*;
import java.util.Date;

@RestController
public class DBController {
    private static String url = "jdbc:sqlite:C:\\Users\\talepis\\Desktop\\medical\\medicine.db";

    @RequestMapping("/allingreek")
    public String listActiveSubstances(){
        return selectAll();
    }
    private String selectAll(){
        StringBuilder sb = new StringBuilder();
        try {
            Connection conn = DriverManager.getConnection(url);
            Statement statement = conn.createStatement();
            ResultSet resultSet = statement.executeQuery("SELECT GreekName FROM ActiveSubstance");
            while (resultSet.next()){
                sb.append(resultSet.getString("GreekName"));
                sb.append("<br/>");
            }
            conn.close();
        } catch (SQLException e) {
            sb.append(e.getMessage());
        }
        return sb.toString();
    }

    @GetMapping("/ActiveSubstances")
    public List<ActiveSubstance> fetchAll(){
        List<ActiveSubstance> list = new ArrayList<>();
        try {
            Connection conn = DriverManager.getConnection(url);
            Statement statement = conn.createStatement();
            ResultSet resultSet = statement.executeQuery("SELECT * FROM ActiveSubstance");
            while (resultSet.next()){
                ActiveSubstance activeSubstance = new ActiveSubstance(resultSet.getString("ID"),
                        resultSet.getString("GreekName"),
                        resultSet.getString("EngName"),
                        resultSet.getString("Description"));
                list.add(activeSubstance);
            }
            conn.close();
        } catch (SQLException e) {

        }
        return list;
    }
    @GetMapping("/ActiveSubstance/{id}")
    public ActiveSubstance show(@PathVariable String id){
        ActiveSubstance activeSubstance = null;
        try {
            Connection conn = DriverManager.getConnection(url);
            PreparedStatement statement = conn.prepareStatement("SELECT * FROM ActiveSubstance WHERE id=?");
            statement.setString(1,id);
            ResultSet resultSet = statement.executeQuery();
            if (resultSet.next()){
                activeSubstance = new ActiveSubstance(resultSet.getString("ID"),
                        resultSet.getString("GreekName"),
                        resultSet.getString("EngName"),
                        resultSet.getString("Description"));
            }
            conn.close();
        } catch (SQLException e) {

        }
        return activeSubstance;
    }
    @PostMapping("/ActiveSubstances")
    public Map<String,String> insert(@RequestBody Map<String, String> body){
        String id = body.get("id");
        String greekname = body.get("greekname");
        String engname = body.get("engname");
        String description = body.get("description");
        try {
            Connection conn = DriverManager.getConnection(url);
            PreparedStatement statement = conn.prepareStatement("INSERT INTO ActiveSubstance (ID, GreekName, EngName, Description) VALUES(?,?,?,?)");
            statement.setString(1,id);
            statement.setString(2,greekname);
            statement.setString(3,engname);
            statement.setString(4,description);
            statement.execute();
            conn.close();
        } catch (SQLException e) {
            String exMessage = e.getLocalizedMessage();
            return new HashMap<String, String>(){{put("message",exMessage);}};
        }
        return new HashMap<String, String>(){{put("message","Active Substance submitted succesfully");}};
    }
    @PutMapping("/ActiveSubstance/{id}")
    public ActiveSubstance update(@PathVariable String id, @RequestBody Map<String,String> body){
        String iD = id;
        String greekname = body.get("greekname");
        String engname = body.get("engname");
        String description = body.get("description");
        try {
            Connection conn = DriverManager.getConnection(url);
            PreparedStatement statement = conn.prepareStatement("UPDATE ActiveSubstance SET GreekName=?,EngName=?,Description=? WHERE ID=?");
            statement.setString(1,greekname);
            statement.setString(2,engname);
            statement.setString(3,description);
            statement.setString(4,iD);
            statement.execute();
            conn.close();
        } catch (SQLException e) {

        }
        return new ActiveSubstance(iD,greekname,engname,description);
    }
    @DeleteMapping("/ActiveSubstance/{id}")
    public Map<String,String> delete(@PathVariable String id){
        String message;
        try {
            Connection conn = DriverManager.getConnection(url);
            PreparedStatement statement = conn.prepareStatement("DELETE FROM ActiveSubstance WHERE ID=?");
            statement.setString(1,id);
            statement.execute();
            conn.close();
            message = "Active substance deleted succesfully";
        } catch (SQLException e) {
            message = e.getMessage();
        }
        final String finalMessage = message;
        return new HashMap<String, String>(){{put("message", finalMessage);}};
    }
}
